@@ -1,11 +1,13 @@
 "SpatialPoints" = function(coords, proj4string = CRS(as.character(NA)),
         bbox=NULL) {
 	coords = coordinates(coords) # checks numeric mode
-	colnames = dimnames(coords)[[2]]
-	if (is.null(colnames))
-		colnames = paste("coords.x", 1:(dim(coords)[2]), sep = "")
-	dimnames(coords) = list(NULL, colnames) # strip row names
-        if (is.null(bbox)) bbox <- .bboxCoords(coords)
+	colNames = dimnames(coords)[[2]]
+	if (is.null(colNames))
+		colNames = paste("coords.x", 1:(dim(coords)[2]), sep = "")
+	rowNames = dimnames(coords)[[1]]
+	dimnames(coords) = list(rowNames, colNames) # preserve row names if non-NULL
+	if (is.null(bbox)) 
+		bbox <- .bboxCoords(coords)
 	new("SpatialPoints", coords = coords, bbox = bbox,
 		proj4string = proj4string) # transpose bbox?
 }
